@@ -119,7 +119,9 @@ bar")))
   (should
    (equal
     (helpful--docstring #'test-foo-advised t)
-    "Docstring here too.")))
+    (if (version< emacs-version "28")
+        "Docstring here too."
+    "Docstring here too.\n\nThis function has :around advice: `ad-Advice-test-foo-advised'."))))
 
 (defun test-foo-no-docstring ()
   nil)
@@ -291,7 +293,16 @@ symbol (not a form)."
      (get-text-property 0 'button formatted)))
   ;; If we have quotes around a key sequence, we should not propertize
   ;; it as the button styling will no longer be visible.
-  (-let [formatted (helpful--format-docstring "`\\[set-mark-command]'")]
+  (-let* ((emacs-major-version 28)
+         (formatted (helpful--format-docstring "`\\[set-mark-command]'")))
+    (should
+     (string-equal formatted "C-SPC"))
+    (should
+     (eq
+      (get-text-property 0 'face formatted)
+      'help-key-binding)))
+  (-let* ((emacs-major-version 27)
+         (formatted (helpful--format-docstring "`\\[set-mark-command]'")))
     (should
      (string-equal formatted "C-SPC"))
     (should
@@ -1055,6 +1066,15 @@ find the source code."
   (should
    (s-contains-p "Original Value\n123" (buffer-string))))
 
+(ert-deftest helpful--preserve-position ()
+  "Show the original value for defcustom variables."
+  (-let [(buf _pos _opened) (helpful--definition 'helpful-test-custom-var nil)]
+    (with-current-buffer buf
+      (goto-char (point-min))
+      (save-current-buffer
+        (helpful-variable 'helpful-test-custom-var))
+      (should (eq (point) (point-min))))))
+
 (ert-deftest helpful--package-version ()
   "Report when a variable was added"
   (helpful-variable 'helpful-test-custom-var)
